summaryrefslogtreecommitdiff
path: root/features
diff options
context:
space:
mode:
Diffstat (limited to 'features')
-rw-r--r--features/user/cli/shells/nushell/default.nix2
-rw-r--r--features/user/gui/apps/foot.nix8
-rwxr-xr-xfeatures/user/gui/desktops/niri/default.nix1
-rw-r--r--features/user/gui/desktops/niri/keybinds.nix2
-rwxr-xr-xfeatures/user/gui/desktops/niri/parts/ignis/default.nix21
-rw-r--r--features/user/gui/desktops/niri/parts/quickshell/.envrc1
-rw-r--r--features/user/gui/desktops/niri/parts/quickshell/flake.lock64
-rw-r--r--features/user/gui/desktops/niri/parts/quickshell/flake.nix29
-rw-r--r--features/user/gui/desktops/niri/parts/selectors.nix16
9 files changed, 112 insertions, 32 deletions
diff --git a/features/user/cli/shells/nushell/default.nix b/features/user/cli/shells/nushell/default.nix
index b8abba5..988308c 100644
--- a/features/user/cli/shells/nushell/default.nix
+++ b/features/user/cli/shells/nushell/default.nix
@@ -68,7 +68,7 @@ in {
let template_path = "${./direnv-project-template}" | path expand
let template_files = ls -a $template_path | get name
$template_files | each {|item| cp $item $path}
- ls -a $path | get name | filter {|name| $template_files | str contains ($name | path basename) | any {}} | each {|name| chmod +w $name}
+ ls -a $path | get name | where {|name| $template_files | str contains ($name | path basename) | any {}} | each {|name| chmod +w $name}
if (try {git rev-parse --is-inside-work-tree e> /dev/null}) != null {
direnv allow
} else {
diff --git a/features/user/gui/apps/foot.nix b/features/user/gui/apps/foot.nix
index d099e16..321e7e8 100644
--- a/features/user/gui/apps/foot.nix
+++ b/features/user/gui/apps/foot.nix
@@ -1,11 +1,15 @@
-{ config, pkgs, lib, ... }: let
+{
+ config,
+ pkgs,
+ lib,
+ ...
+}: let
cfg = config.features.gui.apps.foot;
in {
options.features.gui.apps.foot.enable = lib.mkEnableOption "foot";
config = lib.mkIf cfg.enable {
programs.foot = {
enable = true;
- server.enable = true;
settings = {
main.pad = "0x4";
};
diff --git a/features/user/gui/desktops/niri/default.nix b/features/user/gui/desktops/niri/default.nix
index cd904de..6304c66 100755
--- a/features/user/gui/desktops/niri/default.nix
+++ b/features/user/gui/desktops/niri/default.nix
@@ -20,7 +20,6 @@ in {
selectors.enable = true;
swww.enable = true;
mako.enable = true;
- ignis.enable = true;
hyprlock.enable = true;
};
programs.niri = {
diff --git a/features/user/gui/desktops/niri/keybinds.nix b/features/user/gui/desktops/niri/keybinds.nix
index 5426ee6..c9b0245 100644
--- a/features/user/gui/desktops/niri/keybinds.nix
+++ b/features/user/gui/desktops/niri/keybinds.nix
@@ -12,7 +12,7 @@
right = "l";
in {
# App Launching Keys
- "Mod+Q".action.spawn = ["footclient"];
+ "Mod+Q".action.spawn = ["foot"];
"Mod+W".action.spawn = ["qutebrowser"];
"Mod+Shift+W".action.spawn = ["librewolf"];
"Mod+E".action.spawn = ["neovide"];
diff --git a/features/user/gui/desktops/niri/parts/ignis/default.nix b/features/user/gui/desktops/niri/parts/ignis/default.nix
deleted file mode 100755
index c609ca9..0000000
--- a/features/user/gui/desktops/niri/parts/ignis/default.nix
+++ /dev/null
@@ -1,21 +0,0 @@
-{ config, pkgs, lib, inputs, ... }: let
- cfg = config.features.gui.desktops.niri.parts.ignis;
-in {
- options.features.gui.desktops.niri.parts.ignis.enable = lib.mkEnableOption "ignis";
- config = lib.mkIf cfg.enable {
- home.packages = [
- inputs.ignis.packages.${pkgs.system}.ignis
- pkgs.python3
- ];
- # home.file."ignis-config" = {
- # target = ".config/ignis/config.py";
- # src = ./config.py;
- # };
- # home.file."ignis-style" = {
- # target = ".config/ignis/style.scss";
- # text = /*scss*/ ''
-
- # '';
- # };
- };
-}
diff --git a/features/user/gui/desktops/niri/parts/quickshell/.envrc b/features/user/gui/desktops/niri/parts/quickshell/.envrc
new file mode 100644
index 0000000..3550a30
--- /dev/null
+++ b/features/user/gui/desktops/niri/parts/quickshell/.envrc
@@ -0,0 +1 @@
+use flake
diff --git a/features/user/gui/desktops/niri/parts/quickshell/flake.lock b/features/user/gui/desktops/niri/parts/quickshell/flake.lock
new file mode 100644
index 0000000..29f5851
--- /dev/null
+++ b/features/user/gui/desktops/niri/parts/quickshell/flake.lock
@@ -0,0 +1,64 @@
+{
+ "nodes": {
+ "flake-utils": {
+ "inputs": {
+ "systems": [
+ "systems"
+ ]
+ },
+ "locked": {
+ "lastModified": 1731533236,
+ "narHash": "sha256-l0KFg5HjrsfsO/JpG+r7fRrqm12kzFHyUHqHCVpMMbI=",
+ "owner": "numtide",
+ "repo": "flake-utils",
+ "rev": "11707dc2f618dd54ca8739b309ec4fc024de578b",
+ "type": "github"
+ },
+ "original": {
+ "owner": "numtide",
+ "repo": "flake-utils",
+ "type": "github"
+ }
+ },
+ "nixpkgs": {
+ "locked": {
+ "lastModified": 1751498133,
+ "narHash": "sha256-QWJ+NQbMU+NcU2xiyo7SNox1fAuwksGlQhpzBl76g1I=",
+ "owner": "NixOS",
+ "repo": "nixpkgs",
+ "rev": "d55716bb59b91ae9d1ced4b1ccdea7a442ecbfdb",
+ "type": "github"
+ },
+ "original": {
+ "owner": "NixOS",
+ "ref": "nixpkgs-unstable",
+ "repo": "nixpkgs",
+ "type": "github"
+ }
+ },
+ "root": {
+ "inputs": {
+ "flake-utils": "flake-utils",
+ "nixpkgs": "nixpkgs",
+ "systems": "systems"
+ }
+ },
+ "systems": {
+ "locked": {
+ "lastModified": 1681028828,
+ "narHash": "sha256-Vy1rq5AaRuLzOxct8nz4T6wlgyUR7zLU309k9mBC768=",
+ "owner": "nix-systems",
+ "repo": "default",
+ "rev": "da67096a3b9bf56a91d16901293e51ba5b49a27e",
+ "type": "github"
+ },
+ "original": {
+ "owner": "nix-systems",
+ "repo": "default",
+ "type": "github"
+ }
+ }
+ },
+ "root": "root",
+ "version": 7
+}
diff --git a/features/user/gui/desktops/niri/parts/quickshell/flake.nix b/features/user/gui/desktops/niri/parts/quickshell/flake.nix
new file mode 100644
index 0000000..2122f1f
--- /dev/null
+++ b/features/user/gui/desktops/niri/parts/quickshell/flake.nix
@@ -0,0 +1,29 @@
+{
+ description = "Project flake";
+
+ inputs = {
+ nixpkgs.url = "github:NixOS/nixpkgs/nixpkgs-unstable";
+ systems.url = "github:nix-systems/default";
+ flake-utils = {
+ url = "github:numtide/flake-utils";
+ inputs.systems.follows = "systems";
+ };
+ };
+
+ outputs = {
+ nixpkgs,
+ flake-utils,
+ ...
+ }:
+ flake-utils.lib.eachDefaultSystem (
+ system: let
+ pkgs = nixpkgs.legacyPackages.${system};
+ in {
+ devShells.default = pkgs.mkShell {
+ packages = with pkgs; [
+ quickshell
+ ];
+ };
+ }
+ );
+}
diff --git a/features/user/gui/desktops/niri/parts/selectors.nix b/features/user/gui/desktops/niri/parts/selectors.nix
index 6550a9f..1adc917 100644
--- a/features/user/gui/desktops/niri/parts/selectors.nix
+++ b/features/user/gui/desktops/niri/parts/selectors.nix
@@ -22,20 +22,20 @@ in {
let tools = {
"rebuild nixos": {
# footclient -H sudo nixos-rebuild switch --flake ($"~/Sync/setup#(hostname)" | path expand)
- footclient -H nh os switch
+ foot -H nh os switch
}
"rebuild home": {
- # footclient -H home-manager switch --flake ($"~/Sync/setup#(whoami)@(hostname)" | path expand)
- footclient -H nh home switch
+ # foot -H home-manager switch --flake ($"~/Sync/setup#(whoami)@(hostname)" | path expand)
+ foot -H nh home switch
}
"update flake": {
- footclient -H nix flake update --flake ($"~/Sync/setup/" | path expand)
+ foot -H nix flake update --flake ($"~/Sync/setup/" | path expand)
}
"manage wifi": {
- footclient ${pkgs.impala}/bin/impala
+ foot ${pkgs.impala}/bin/impala
}
"manage bluetooth": {
- footclient ${lib.getExe pkgs.bluetui}
+ foot ${lib.getExe pkgs.bluetui}
}
"create qr-code": {
let temp_file = mktemp
@@ -44,6 +44,10 @@ in {
$qr_code_bin | save -f $temp_file
${lib.getExe pkgs.imv} $temp_file
}
+ "steam big-picture": {
+ rm -r ~/.steam
+ gamescope -f --backend sdl -- steam -bigpicture
+ }
}
# Logic